@@ -8,22 +8,11 @@ use PulseAudio::Backend::Utilities;
 
 use Moose;
 
+with 'PulseAudio::Roles::Object';
+
 use PulseAudio::Types qw(PA_Index);
-
 has 'index' => ( isa => PA_Index, is => 'ro', required => 1 );
 
-has '_dump' => (
-	isa        => 'HashRef'
-	, is       => 'ro'
-	, required => 1
-	, init_arg => 'dump'
-	, traits   => ['Hash']
-
-	, handles  => {
-		'get' => 'get'
-	}
-);
-
 foreach my $cmd ( @{_commands()} ) {
 	__PACKAGE__->meta->add_method( $cmd->{alias} => $cmd->{sub} );
 }
